@@ -1,7 +1,7 @@
 package App::depak;
 
-our $DATE = '2016-02-29'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-08-02'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use strict;
@@ -103,7 +103,7 @@ sub _build_lib {
             $log->debugf("  Adding modules: %s (included dist)", join(", ", @distmods));
             $mod_paths{$_} = undef for @distmods;
         } else {
-            $log->debugf("  Adding module: %s (included dist, but can't find other modules)", $_);
+            $log->infof("  Adding module: %s (included dist, but can't find other modules)", $_);
             $mod_paths{$_} = undef;
         }
     }
@@ -658,13 +658,16 @@ _
             summary => 'Instead of dying, skip when module to add is not found',
             'summary.alt.bool.not' => 'Instead of skipping, die when module to add is not found',
             schema => ['bool'],
-            default => 1,
             description => <<'_',
 
 This option is useful when you use `include_prereq`, because modules without its
 own .pm files will also be included (CPAN indexes packages, including those that
 do not have their own .pm files).
 
+By default, this option is turned off unless when you use `include_prereq` where
+this option is by default turned on. You can of course override the default by
+explicitly specify this option.
+
 _
             tags => ['category:module-selection'],
         },
@@ -778,6 +781,8 @@ sub depak {
 
     $self->{debug_keep_tempdir} //= $ENV{DEBUG_KEEP_TEMPDIR} // 0;
 
+    $self->{skip_not_found} //= $self->{include_prereq} ? 1:0;
+
     my $tempdir = File::Temp::tempdir(CLEANUP => 0);
     $log->debugf("Created tempdir %s", $tempdir);
     $self->{tempdir} = $tempdir;
@@ -964,7 +969,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.52 of App::depak (from Perl distribution App-depak), released on 2016-02-29.
+This document describes version 0.53 of App::depak (from Perl distribution App-depak), released on 2016-08-02.
 
 =head1 SYNOPSIS
 
@@ -979,7 +984,7 @@ See L<depak>.
 
 Pack your dependencies onto your script file.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -1128,7 +1133,7 @@ different sets of core modules as well as different versions of the modules.
 
 Set shebang line/path.
 
-=item * B<skip_not_found> => I<bool> (default: 1)
+=item * B<skip_not_found> => I<bool>
 
 Instead of dying, skip when module to add is not found.
 
@@ -1136,6 +1141,10 @@ This option is useful when you use C<include_prereq>, because modules without it
 own .pm files will also be included (CPAN indexes packages, including those that
 do not have their own .pm files).
 
+By default, this option is turned off unless when you use C<include_prereq> where
+this option is by default turned on. You can of course override the default by
+explicitly specify this option.
+
 =item * B<squish> => I<bool> (default: 0)
 
 Whether to squish included modules using Perl::Squish.
